"""
Unit tests covering telliot_core CLI commands.
"""
import pytest

# from telliot_feed_examples.cli import cli

# from click.testing import CliRunner


@pytest.mark.skip("TODO after telliot-core cli output cleaned up.")
def test_cmd_legacyid():
    """Test telliot_core CLI command: report."""
    # cli.input = lambda: "1234.1234"
    # runner = CliRunner()
    # result = runner.invoke(main, ["report", "legacyid"])

    # assert result.exit_code == 1
    # assert result.output == "Given legacy id(s) not supported."

    # TODO: uncomment after pr is merged:
    # https://github.com/tellor-io/telliot-core/pull/149
    pass
